/**********************************************************************
Copyright (c) 2006 Thomas Marti, Stefan Schmid and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
2006 Erik Bengtson - Original implementation
    ...
**********************************************************************/
package org.datanucleus.store.mapped.mapping.jgeom;

import oracle.spatial.geometry.JGeometry;

import org.datanucleus.store.expression.spatial.GeometryLiteral;
import org.datanucleus.store.expression.spatial.GeometryScalarExpression;
import org.datanucleus.ClassLoaderResolver;
import org.datanucleus.store.mapped.expression.LogicSetExpression;
import org.datanucleus.store.mapped.expression.QueryExpression;
import org.datanucleus.store.mapped.expression.ScalarExpression;
import org.datanucleus.store.mapped.mapping.SingleFieldMapping;

/**
 * Mapping for oracle.spatial.geometry.JGeometry to its datastore representation.
 */
public class JGeometryMapping extends SingleFieldMapping
{
    private static final JGeometry sampleValue = JGeometry.createCircle(1, 1, 1, 1, 1, 1, 1);

    public Class getJavaType()
    {
        return JGeometry.class;
    }

    public Object getSampleValue(ClassLoaderResolver clr)
    {
        return sampleValue;
    }

    // TODO Drop these when we drop legacy support
    public ScalarExpression newLiteral(QueryExpression qs, Object value)
    {
        return new GeometryLiteral(qs, this, value);
    }

    public ScalarExpression newScalarExpression(QueryExpression qs, LogicSetExpression te)
    {
        return new GeometryScalarExpression(qs, this, te);
    }
}